require "devise"

module Identity
  module Mixins
    autoload :User, 'identity/mixins/user'
  end

  mattr_accessor :devise_modules do
    [
      :database_authenticatable,
      :registerable,
      :recoverable,
      :rememberable,
      :trackable,
      :validatable
    ]
  end

  mattr_accessor(:user_class_name) { "::User" }
  mattr_accessor(:layout) { 'application' }
  mattr_accessor(:auth_routes) { {} }
  mattr_accessor(:active_scope) { :all }

  def self.user_class
    user_class_name.constantize
  end

  def self.controllers
    if Devise.omniauth_providers.any?
      { omniauth_callbacks: "identity/omniauth_callbacks" }
    else
      {  }
    end
  end

  def self.setup
    yield self
  end

  def self.method_missing(name, *args, &block)
    if delegate_to_devise?(name.to_s)
      Devise.public_send(name, *args, &block)
    else
      super
    end
  end

  def self.delegate_to_devise?(name)
    name.in?(%w(omniauth)) ||
    name.ends_with?('=') && Devise.respond_to?(name)
  end

  def self.respond_to_missing?(name, include_private = false)
    (name.to_s.ends_with?('=') && Devise.respond_to?(name, include_private)) || super
  end

end

require "identity/engine"
