module Identity
  module Mixins
    module User
      def self.included(base)
        base.devise *Identity.devise_modules
        base.extend ClassMethods

        if Devise.omniauth_providers.any?
          base.devise :omniauthable, omniauth_providers: Devise.omniauth_providers
        end
      end

      def build_from_auth(auth)
        auth_provider = auth.provider.gsub(/\_/, '-')
        self.email = "#{auth.uid}@#{auth_provider}.com"
        self.password = Devise.friendly_token[0,20]
        self.oauth_hash = auth

        send("build_from_#{auth.provider}", auth) if respond_to?("build_from_#{auth.provider}")
      end

      module ClassMethods
        def from_omniauth!(auth)
          where(provider: auth.provider, uid: auth.uid).first_or_create! do |user|
            user.build_from_auth auth
          end
        end

        def find_first_by_auth_conditions(tainted_conditions, opts = {})
          super(tainted_conditions, send(Identity.active_scope).where_values_hash.merge(opts))
        end

        def active
          result = where(active: true)
          result = result.where.not(confirmed_at: nil) if devise_modules.include?(:confirmable)
          result
        end
      end
    end
  end
end
